#
# Init
#

# import global modules
import configparser
import importlib

def init():
    global config
    config = configparser.ConfigParser()
    config.read('config.ini')

    global commands
    commands = {}

def addCommandAction(command, instance, function):
    if command in commands.keys():
        commands[command].append([instance, function])
    else:
        commands[command] = [[instance, function]]


def executeCommandAction(command, message):
    if command in commands.keys():
        for instanceArray in commands[command]:
            instance = instanceArray[0]
            callableMethod = getattr(instance, instanceArray[1])
            return callableMethod(message)



#
# Main
#

# import global modules
import importlib
import init

# initialize all modules configuration options
init.init()

# dynamically load backend modules
backend_modules = init.config['DEFAULT']['BACKEND_MODULES']
backend_modules = backend_modules.split(",")
for moduleName in backend_modules:
    moduleName = moduleName.strip()
    module = importlib.import_module(
        '.' + moduleName,
        'modules.backend.' + moduleName
    )

# dynamically load command modules
command_modules = init.config['DEFAULT']['COMMAND_MODULES']
command_modules = command_modules.split(",")
for moduleName in command_modules:
    moduleName = moduleName.strip()
    module = importlib.import_module(
        '.' + moduleName,
        'modules.command.' + moduleName
    )

# config overrides



from setuptools import setup

setup(
    name='cabot-core',
    packages=['cabot'],
    version='0.1.0',
    license='MIT',
    description='A modular chat bot.',
    author='Joseph Hanna',
    author_email='josephhanna@centennialarts.com',
    url='https://github.com/centennialarts/cabot',
    download_url='https://github.com/centennialarts/cabot/archive/master.zip',
    keywords=['Chatbot', 'IRC', 'API'],
    install_requires=[
        'irc',
        'requests',
    ],
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'Topic :: Communications :: Chat :: Internet Relay Chat',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
    ],
)
